summaryrefslogtreecommitdiffstats
path: root/media/base/key_systems.cc
diff options
context:
space:
mode:
authorjam <jam@chromium.org>2015-05-14 18:50:34 -0700
committerCommit bot <commit-bot@chromium.org>2015-05-15 01:50:47 +0000
commitcd8c1af1fbdaf722ac3c855489282c0c0557d429 (patch)
treeca9e988e6fea305e06baaa40375e935937bea803 /media/base/key_systems.cc
parentea0f35165bfac778916a3e567f31516b12b8fe9d (diff)
downloadchromium_src-cd8c1af1fbdaf722ac3c855489282c0c0557d429.zip
chromium_src-cd8c1af1fbdaf722ac3c855489282c0c0557d429.tar.gz
chromium_src-cd8c1af1fbdaf722ac3c855489282c0c0557d429.tar.bz2
Revert of Plumb |use_secure_codecs| through to BrowserCdmFactoryAndroid. (patchset #6 id:160001 of https://codereview.chromium.org/1131753003/)
Reason for revert: Broke Linux GN clobber: http://build.chromium.org/p/chromium.linux/builders/Linux%20GN%20Clobber/builds/258/steps/compile/logs/stdio Original issue's description: > Plumb |use_secure_codecs| through to BrowserCdmFactoryAndroid. > > This completes the path from the secure surface preference, through requestMediaKeySystemAccess() and finally to CDM creation on Android where secure codecs are enabled. With this change, configs requiring secure codes are rejected without the preference and the CDM is only configures to use hardware-secure codecs if the config requires it. > > There is a separate bug (http://crbug.com/478185) for implementing similar plumbing for the use of secure surfaces. > > BUG=467779 > > Committed: https://crrev.com/9ce0a551c7f1d79dea793b5691473ef9d5fb9326 > Cr-Commit-Position: refs/heads/master@{#330008} TBR=ddorwin@chromium.org,jrummell@chromium.org,gunsch@chromium.org,nasko@chromium.org,gunsch@google.com,sandersd@chromium.org NOPRESUBMIT=true NOTREECHECKS=true NOTRY=true BUG=467779 Review URL: https://codereview.chromium.org/1132773003 Cr-Commit-Position: refs/heads/master@{#330018}
Diffstat (limited to 'media/base/key_systems.cc')
-rw-r--r--media/base/key_systems.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/media/base/key_systems.cc b/media/base/key_systems.cc
index 1cd202c..f38fe7c 100644
--- a/media/base/key_systems.cc
+++ b/media/base/key_systems.cc
@@ -720,10 +720,10 @@ EmeConfigRule KeySystemsImpl::GetContentTypeConfigRule(
//
// Because the check for regular codec support is early-exit, we don't have
// to consider codecs that are only supported in hardware-secure mode. We
// could do so, and make use of HW_SECURE_CODECS_REQUIRED, if it turns out
// that hardware-secure-only codecs actually exist and are useful.
if ((codec & key_system_secure_codec_mask) == 0)
- support = EmeConfigRule::HW_SECURE_CODECS_NOT_ALLOWED;
+ support = EmeConfigRule::SECURE_CODECS_NOT_ALLOWED;
#endif // defined(OS_ANDROID)
}
@@ -786,7 +786,7 @@ EmeConfigRule KeySystemsImpl::GetRobustnessConfigRule(
}
#elif defined(OS_ANDROID)
if (robustness > EmeRobustness::SW_SECURE_CRYPTO)
- return EmeConfigRule::HW_SECURE_CODECS_REQUIRED;
+ return EmeConfigRule::SECURE_CODECS_REQUIRED;
#endif // defined(OS_CHROMEOS)
}
@@ -720,10 +720,10 @@ EmeConfigRule KeySystemsImpl::GetContentTypeConfigRule(
// Because the check for regular codec support is early-exit, we don't have
// to consider codecs that are only supported in hardware-secure mode. We
- // could do so, and make use of HW_SECURE_CODECS_REQUIRED, if it turns out
- // that hardware-secure-only codecs actually exist and are useful.
+ // could do so, and make use of SECURE_CODECS_REQUIRED, if it turns out that
+ // hardware-secure-only codecs actually exist and are useful.
if ((codec & key_system_secure_codec_mask) == 0)